import 'package:string_case_converter/string_case_converter.dart';
import 'package:test/test.dart';

void main() {
  group('Pascal Case', (){

    test('it converts string to PascalCase', () {
      expect('placeholder text'.toPascalCase(), 'PlaceholderText');
    });

    test('it handles numbers', (){
      expect('I got 99 problems But cases Aint one'.toPascalCase(), 'IGot99ProblemsButCasesAintOne');
    });

    test('it removes trailing spaces', () {
      expect('     placeholder text'.toPascalCase(), 'PlaceholderText');
    });

    test('it normalises characters', () {
      expect('buT NaTive DevelopMent Is BetTer'.toPascalCase(), 'ButNativeDevelopmentIsBetter');
    });

    test('it handles acronyms', () {
      expect('base URL'.toPascalCase(), 'BaseURL');
    });

    test('it deals with special characters', () {
      expect('-number of? People'.toPascalCase(), 'NumberOfPeople');
    });

    test('it handles an empty string', (){
      expect(''.toPascalCase(), '');
    });
  });

  group('Camel Case', () {

    test('it converts string to CamelCase', () {
      expect('I got 99 problems But cases Aint one'.toCamelCase(), 'iGot99ProblemsButCasesAintOne');
    });

    test('it removes trailing spaces', () {
      expect('     placeholder text'.toCamelCase(), 'placeholderText');
    });

    test('it normalises characters', () {
      expect('buT NaTive DevelopMent Is BetTer'.toCamelCase(), 'butNativeDevelopmentIsBetter');
    });

    test('it handles acronyms', () {
      expect('base URL'.toCamelCase(), 'baseURL');
    });

    test('it deals with special characters', () {
      expect('-number of? People'.toCamelCase(), 'numberOfPeople');
    });

    test('it handles an empty string', (){
      expect(''.toCamelCase(), '');
    });

  });

  group('Snake Case', () {

    test('it converts string to Snake Case', () {
      expect('I got 99 problems But cases Aint one'.toSnakeCase(), 'i_got_99_problems_but_cases_aint_one');
    });

    test('it removes trailing spaces', () {
      expect('     placeholder text'.toSnakeCase(), 'placeholder_text');
    });

    test('it normalises characters', () {
      expect('buT NaTive DevelopMent Is BetTer'.toSnakeCase(), 'but_native_development_is_better');
    });

    test('it capitalises characters when screaming', () {
      expect('buT NaTive DevelopMent Is BetTer'.toConstantCase(), 'BUT_NATIVE_DEVELOPMENT_IS_BETTER');
    });

    test('it deals with special characters', () {
      expect('-number of? People'.toConstantCase(), 'NUMBER_OF_PEOPLE');
    });

    test('it handles an empty string', (){
      expect(''.toConstantCase(), '');
    });

  });

  group('Kebab Case', () {

    test('it converts string to Snake Case', () {
      expect('I got 99 problems But cases Aint one'.toKebabCase(), 'i-got-99-problems-but-cases-aint-one');
    });

    test('it removes trailing spaces', () {
      expect('     placeholder text'.toKebabCase(), 'placeholder-text');
    });

    test('it normalises characters', () {
      expect('buT NaTive DevelopMent Is BetTer'.toKebabCase(), 'but-native-development-is-better');
    });

    test('it deals with special characters', () {
      expect('-number of? People     *£(£  £}%£%'.toKebabCase(), 'number-of-people');
    });

    test('it handles an empty string', (){
      expect(''.toKebabCase(), '');
    });
  });
}
